@@ -137,7 +137,7 @@ class Account():
             return result
 
         except Exception as e:
-            print(str(e))
+            #print(str(e))
             return None
   
     @staticmethod
@@ -219,6 +219,36 @@ class Account():
             print(str(e))
             sys.exit(1)
     
+    @staticmethod
+    def clone_project(project: str):
+        '''
+        Clone project to current directory
+        
+        @param files Zipfile of project
+        @param data Project Config
+        @return requests response
+        '''
+        
+        try:
+            global BASE_HEADERS
+            token = load_token()
+
+            BASE_HEADERS['Authorization'] = f"Bearer {token}"
+            
+            url = BASE_API + f'projects/clone/{project}/'
+
+            req = requests.get(url, headers=BASE_HEADERS)
+            print(req.headers)
+            result = req.json()
+
+            if 'msg' in result.keys() and len(result['msg']):
+                raise Exception(f"[Error] {result['msg']}")
+            return result
+
+        except Exception as e:
+            print(str(e))
+            sys.exit(1)
+    
     @staticmethod
     def create_project(args):
         '''
